==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/FileattachmentRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Fileattachment;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SolutionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class FileattachmentRequest extends EntityRequest<Fileattachment> {

    public FileattachmentRequest(ContextPath contextPath, Optional<Object> value) {
        super(Fileattachment.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SyncerrorCollectionRequest fileAttachment_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("FileAttachment_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest fileAttachment_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("FileAttachment_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public SolutionRequest fileAttachment_Solution() {
        return new SolutionRequest(contextPath.addSegment("FileAttachment_Solution"), Optional.empty());
    }

    public SolutionCollectionRequest solution_fileid() {
        return new SolutionCollectionRequest(
                        contextPath.addSegment("solution_fileid"), Optional.empty());
    }

    public SolutionRequest solution_fileid(String solutionid) {
        return new SolutionRequest(contextPath.addSegment("solution_fileid").addKeys(new NameValue(solutionid.toString())), Optional.empty());
    }

    public StagesolutionuploadRequest objectid_stagesolutionupload() {
        return new StagesolutionuploadRequest(contextPath.addSegment("objectid_stagesolutionupload"), Optional.empty());
    }

    public ExportsolutionuploadRequest objectid_exportsolutionupload() {
        return new ExportsolutionuploadRequest(contextPath.addSegment("objectid_exportsolutionupload"), Optional.empty());
    }

    public AsyncoperationRequest objectid_asyncoperation() {
        return new AsyncoperationRequest(contextPath.addSegment("objectid_asyncoperation"), Optional.empty());
    }

    public AsyncoperationCollectionRequest fileAttachment_AsyncOperation_DataBlobId() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("FileAttachment_AsyncOperation_DataBlobId"), Optional.empty());
    }

    public AsyncoperationRequest fileAttachment_AsyncOperation_DataBlobId(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("FileAttachment_AsyncOperation_DataBlobId").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public WorkflowlogRequest objectid_workflowlog() {
        return new WorkflowlogRequest(contextPath.addSegment("objectid_workflowlog"), Optional.empty());
    }

    public FlowsessionRequest objectid_flowsession() {
        return new FlowsessionRequest(contextPath.addSegment("objectid_flowsession"), Optional.empty());
    }

    public WorkflowbinaryRequest objectid_workflowbinary() {
        return new WorkflowbinaryRequest(contextPath.addSegment("objectid_workflowbinary"), Optional.empty());
    }

    public Msdyn_knowledgearticleimageRequest objectid_msdyn_knowledgearticleimage() {
        return new Msdyn_knowledgearticleimageRequest(contextPath.addSegment("objectid_msdyn_knowledgearticleimage"), Optional.empty());
    }

    public Msdyn_aiconfigurationRequest objectid_msdyn_aiconfiguration() {
        return new Msdyn_aiconfigurationRequest(contextPath.addSegment("objectid_msdyn_aiconfiguration"), Optional.empty());
    }

    public Msdyn_aibfileRequest objectid_msdyn_aibfile() {
        return new Msdyn_aibfileRequest(contextPath.addSegment("objectid_msdyn_aibfile"), Optional.empty());
    }

    public CascadegrantrevokeaccessrecordstrackerRequest objectid_cascadegrantrevokeaccessrecordstracker() {
        return new CascadegrantrevokeaccessrecordstrackerRequest(contextPath.addSegment("objectid_cascadegrantrevokeaccessrecordstracker"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.49-sources.jar: microsoft/dynamics/crm/entity/request/FileattachmentRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Fileattachment;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SolutionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class FileattachmentRequest extends EntityRequest<Fileattachment> {

    public FileattachmentRequest(ContextPath contextPath, Optional<Object> value) {
        super(Fileattachment.class, contextPath, value);
    }

    public SyncerrorCollectionRequest fileAttachment_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("FileAttachment_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest fileAttachment_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("FileAttachment_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public SolutionRequest fileAttachment_Solution() {
        return new SolutionRequest(contextPath.addSegment("FileAttachment_Solution"), Optional.empty());
    }

    public SolutionCollectionRequest solution_fileid() {
        return new SolutionCollectionRequest(
                        contextPath.addSegment("solution_fileid"), Optional.empty());
    }

    public SolutionRequest solution_fileid(String solutionid) {
        return new SolutionRequest(contextPath.addSegment("solution_fileid").addKeys(new NameValue(solutionid.toString())), Optional.empty());
    }

    public StagesolutionuploadRequest objectid_stagesolutionupload() {
        return new StagesolutionuploadRequest(contextPath.addSegment("objectid_stagesolutionupload"), Optional.empty());
    }

    public ExportsolutionuploadRequest objectid_exportsolutionupload() {
        return new ExportsolutionuploadRequest(contextPath.addSegment("objectid_exportsolutionupload"), Optional.empty());
    }

    public AsyncoperationRequest objectid_asyncoperation() {
        return new AsyncoperationRequest(contextPath.addSegment("objectid_asyncoperation"), Optional.empty());
    }

    public AsyncoperationCollectionRequest fileAttachment_AsyncOperation_DataBlobId() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("FileAttachment_AsyncOperation_DataBlobId"), Optional.empty());
    }

    public AsyncoperationRequest fileAttachment_AsyncOperation_DataBlobId(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("FileAttachment_AsyncOperation_DataBlobId").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public WorkflowlogRequest objectid_workflowlog() {
        return new WorkflowlogRequest(contextPath.addSegment("objectid_workflowlog"), Optional.empty());
    }

    public FlowsessionRequest objectid_flowsession() {
        return new FlowsessionRequest(contextPath.addSegment("objectid_flowsession"), Optional.empty());
    }

    public WorkflowbinaryRequest objectid_workflowbinary() {
        return new WorkflowbinaryRequest(contextPath.addSegment("objectid_workflowbinary"), Optional.empty());
    }

    public Msdyn_knowledgearticleimageRequest objectid_msdyn_knowledgearticleimage() {
        return new Msdyn_knowledgearticleimageRequest(contextPath.addSegment("objectid_msdyn_knowledgearticleimage"), Optional.empty());
    }

    public Msdyn_aiconfigurationRequest objectid_msdyn_aiconfiguration() {
        return new Msdyn_aiconfigurationRequest(contextPath.addSegment("objectid_msdyn_aiconfiguration"), Optional.empty());
    }

    public Msdyn_aibfileRequest objectid_msdyn_aibfile() {
        return new Msdyn_aibfileRequest(contextPath.addSegment("objectid_msdyn_aibfile"), Optional.empty());
    }

    public CascadegrantrevokeaccessrecordstrackerRequest objectid_cascadegrantrevokeaccessrecordstracker() {
        return new CascadegrantrevokeaccessrecordstrackerRequest(contextPath.addSegment("objectid_cascadegrantrevokeaccessrecordstracker"), Optional.empty());
    }

}
